@@ -28,16 +28,16 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkstock.h>
-#include "giggle-marshal.h"
+#include "libgiggle/giggle-marshal.h"
 
 typedef struct GiggleShortListPriv GiggleShortListPriv;
 
 struct GiggleShortListPriv {
-	GtkWidget   * label;
-	GtkWidget   * content_box;
-	GtkWidget   * more_button;
+	GtkWidget    *label;
+	GtkWidget    *content_box;
+	GtkWidget    *more_button;
 
-	GtkTreeModel* model;
+	GtkTreeModel *model;
 };
 
 enum {
@@ -292,8 +292,9 @@ short_list_show_dialog (GiggleShortList* self)
 }
 
 static gboolean
-short_list_update_label_idle (GiggleShortList* self)
+short_list_update_label_idle (gpointer user_data)
 {
+	GiggleShortList     *self = user_data;
 	GiggleShortListPriv *priv;
 	GtkTreeIter          iter;
 	gboolean             valid;
@@ -337,10 +338,10 @@ short_list_update_label_idle (GiggleShortList* self)
 static void
 short_list_update_label (GiggleShortList* self)
 {
-	g_idle_add_full (G_PRIORITY_LOW,
-			 (GSourceFunc)short_list_update_label_idle,
-			 g_object_ref (self),
-			 g_object_unref);
+	gdk_threads_add_idle_full (G_PRIORITY_LOW,
+				   short_list_update_label_idle,
+				   g_object_ref (self),
+				   g_object_unref);
 }
 
 static void
@@ -371,7 +372,7 @@ giggle_short_list_init (GiggleShortList *self)
 	priv->content_box = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (self), priv->content_box, TRUE, TRUE, 0);
 
-	priv->more_button = gtk_button_new_with_label (_("Show all..."));
+	priv->more_button = gtk_button_new_with_mnemonic (_("Show A_ll..."));
 	gtk_box_pack_end (GTK_BOX (self), priv->more_button, FALSE, FALSE, 0);
 	g_signal_connect_swapped (priv->more_button, "clicked",
 				  G_CALLBACK (short_list_show_dialog), self);
